==> alfresco-remote-api-23.3.21.2-sources.jar: org/alfresco/repo/web/scripts/RepositoryTemplateProcessorFactory.java <==
/*
 * #%L
 * Alfresco Remote API
 * %%
 * Copyright (C) 2005 - 2016 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.alfresco.repo.web.scripts;

import org.springframework.extensions.webscripts.TemplateProcessor;
import org.springframework.extensions.webscripts.TemplateProcessorFactory;

/**
 * @author Kevin Roast
 */
public class RepositoryTemplateProcessorFactory implements TemplateProcessorFactory
{
    private TemplateProcessor templateProcessor;
    
    
    /**
     * @param templateProcessor     the TemplateProcessor to set
     */
    public void setTemplateProcessor(TemplateProcessor templateProcessor)
    {
        this.templateProcessor = templateProcessor;
    }

    /* (non-Javadoc)
     * @see org.springframework.extensions.webscripts.TemplateProcessorFactory#newInstance()
     */
    public TemplateProcessor newInstance()
    {
        return templateProcessor;
    }
}

==> alfresco-remote-api-26.1.0.21-sources.jar: org/alfresco/repo/web/scripts/RepositoryTemplateProcessorFactory.java <==
/*
 * #%L
 * Alfresco Remote API
 * %%
 * Copyright (C) 2005 - 2016 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.alfresco.repo.web.scripts;

import org.springframework.extensions.webscripts.TemplateProcessor;
import org.springframework.extensions.webscripts.TemplateProcessorFactory;

/**
 * @author Kevin Roast
 */
public class RepositoryTemplateProcessorFactory implements TemplateProcessorFactory
{
    private TemplateProcessor templateProcessor;

    /**
     * @param templateProcessor
     *            the TemplateProcessor to set
     */
    public void setTemplateProcessor(TemplateProcessor templateProcessor)
    {
        this.templateProcessor = templateProcessor;
    }

    /* (non-Javadoc)
     * 
     * @see org.springframework.extensions.webscripts.TemplateProcessorFactory#newInstance() */
    public TemplateProcessor newInstance()
    {
        return templateProcessor;
    }
}
